Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS IoT Greengrass V2.

Actions, resources, and condition keys for AWS IoT Greengrass V2 - Service Authorization Reference

# Actions, resources, and condition keys for AWS IoT Greengrass V2

AWS IoT Greengrass V2 (service prefix: `greengrass` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS IoT Greengrass V2
- Resource types defined by AWS IoT Greengrass V2
- Condition keys for AWS IoT Greengrass V2

## Actions defined by AWS IoT Greengrass V2

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CancelDeployment | Grants permission to cancel a deployment | Write | deployment* |  | iot:CancelJob iot:DeleteThingShadow iot:DescribeJob iot:DescribeThing iot:DescribeThingGroup iot:GetThingShadow iot:UpdateJob iot:UpdateThingShadow
CreateComponentVersion | Grants permission to create a component | Write | component* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateDeployment | Grants permission to create a deployment | Write |  | aws:RequestTag/${TagKey} aws:TagKeys | iot:CancelJob iot:CreateJob iot:DeleteThingShadow iot:DescribeJob iot:DescribeThing iot:DescribeThingGroup iot:GetThingShadow iot:UpdateJob iot:UpdateThingShadow
DeleteComponent | Grants permission to delete a component | Write | componentVersion* |  |
DeleteCoreDevice | Grants permission to delete a AWS IoT Greengrass core device, which is an AWS IoT thing. This operation removes the core device from the list of core devices. This operation doesn't delete the AWS IoT thing | Write | coreDevice* |  | iot:DescribeJobExecution
DescribeComponent | Grants permission to retrieve metadata for a version of a component | Read | componentVersion* |  |
GetComponent | Grants permission to get the recipe for a version of a component | Read | componentVersion* |  |
GetCoreDevice | Grants permission to retrieves metadata for a AWS IoT Greengrass core device | Read | coreDevice* |  |
GetDeployment | Grants permission to get a deployment | Read | deployment* |  | iot:DescribeJob iot:DescribeThing iot:DescribeThingGroup iot:GetThingShadow
ListComponentVersions | Grants permission to retrieve a paginated list of all versions for a component | List | component* |  |
ListComponents | Grants permission to retrieve a paginated list of component summaries | List |  |  |
ListCoreDevices | Grants permission to retrieve a paginated list of AWS IoT Greengrass core devices | List |  |  |
ListDeployments | Grants permission to retrieves a paginated list of deployments | List |  |  | iot:DescribeJob iot:DescribeThing iot:DescribeThingGroup iot:GetThingShadow
ListEffectiveDeployments | Grants permission to retrieves a paginated list of deployment jobs that AWS IoT Greengrass sends to AWS IoT Greengrass core devices | List | coreDevice* |  | iot:DescribeJob iot:DescribeJobExecution iot:DescribeThing iot:DescribeThingGroup iot:GetThingShadow
ListInstalledComponents | Grants permission to retrieve a paginated list of the components that a AWS IoT Greengrass core device runs | List | coreDevice* |  |
ListTagsForResource | Grants permission to list the tags for a resource | List | component |  |
componentVersion |  |
coreDevice |  |
deployment |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
TagResource | Grants permission to add tags to a resource | Tagging | component |  |
componentVersion |  |
coreDevice |  |
deployment |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to remove tags from a resource | Tagging | component |  |
componentVersion |  |
coreDevice |  |
deployment |  |
| aws:RequestTag/${TagKey} aws:TagKeys |

## Resource types defined by AWS IoT Greengrass V2

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
component | `arn:$ { Partition}:greengrass:$ { Region}:$ { Account}:components:$ { ComponentName}` | aws:ResourceTag/${TagKey}
componentVersion | `arn:$ { Partition}:greengrass:$ { Region}:$ { Account}:components:$ { ComponentName}:versions:$ { ComponentVersion}` | aws:ResourceTag/${TagKey}
coreDevice | `arn:$ { Partition}:greengrass:$ { Region}:$ { Account}:coreDevices:$ { CoreDeviceThingName}` | aws:ResourceTag/${TagKey}
deployment | `arn:$ { Partition}:greengrass:$ { Region}:$ { Account}:deployments:$ { DeploymentId}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS IoT Greengrass V2

AWS IoT Greengrass V2 defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:CurrentTime | Filters access by checking date/time conditions for the current date and time | Date
aws:EpochTime | Filters access by checking date/time conditions for the current date and time in epoch or Unix time | Date
aws:MultiFactorAuthAge | Filters access by checking how long ago (in seconds) the security credentials validated by multi-factor authentication (MFA) in the request were issued using MFA | Numeric
aws:MultiFactorAuthPresent | Filters access by checking whether multi-factor authentication (MFA) was used to validate the temporary security credentials that made the current request | Boolean
aws:RequestTag/${TagKey} | Filters create requests based on the allowed set of values for each of the mandatory tags | String
aws:ResourceTag/${TagKey} | Filters actions based on the tag value associated with the resource | String
aws:SecureTransport | Filters access by checking whether the request was sent using SSL | Boolean
aws:TagKeys | Filters create requests based on the presence of mandatory tags in the request | String
aws:UserAgent | Filters access by the requester's client application | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.